@@ -4,21 +4,19 @@ import sys
 import uuid
 from http import HTTPStatus
 
-from fps.config import Config  # type: ignore
 from fps.hooks import register_router  # type: ignore
 from fastapi import APIRouter, WebSocket, Response, Depends, status
 from fastapi.responses import FileResponse
-from kernel_server import KernelServer  # type: ignore
 from starlette.requests import Request  # type: ignore
 
-from fps_auth.routes import cookie_authentication, users  # type: ignore
+from fps_auth.routes import cookie_authentication, current_user  # type: ignore
 from fps_auth.models import User, user_db  # type: ignore
-from fps_auth.config import AuthConfig  # type: ignore
+from fps_auth.config import get_auth_config  # type: ignore
 
+from .kernel_server.server import KernelServer  # type: ignore
 from .models import Session
 
 router = APIRouter()
-auth_config = Config(AuthConfig)
 
 kernelspecs: dict = {}
 sessions: dict = {}
@@ -76,7 +74,7 @@ async def get_kernels():
 @router.delete("/api/sessions/{session_id}", status_code=204)
 async def delete_session(
     session_id: str,
-    user: User = Depends(users.current_user(optional=auth_config.disable_auth)),
+    user: User = Depends(current_user()),
 ):
     kernel_id = sessions[session_id]["kernel"]["id"]
     kernel_server = kernels[kernel_id]["server"]
@@ -89,7 +87,7 @@ async def delete_session(
 @router.patch("/api/sessions/{session_id}")
 async def rename_session(
     request: Request,
-    user: User = Depends(users.current_user(optional=auth_config.disable_auth)),
+    user: User = Depends(current_user()),
 ):
     rename_session = await request.json()
     session_id = rename_session.pop("id")
@@ -117,7 +115,7 @@ async def get_sessions():
 )
 async def create_session(
     request: Request,
-    user: User = Depends(users.current_user(optional=auth_config.disable_auth)),
+    user: User = Depends(current_user()),
 ):
     create_session = await request.json()
     kernel_name = create_session["kernel"]["name"]
@@ -151,7 +149,7 @@ async def create_session(
 @router.post("/api/kernels/{kernel_id}/restart")
 async def restart_kernel(
     kernel_id,
-    user: User = Depends(users.current_user(optional=auth_config.disable_auth)),
+    user: User = Depends(current_user()),
 ):
     if kernel_id in kernels:
         kernel = kernels[kernel_id]
@@ -167,9 +165,11 @@ async def restart_kernel(
 
 
 @router.websocket("/api/kernels/{kernel_id}/channels")
-async def kernel_channels(websocket: WebSocket, kernel_id, session_id):
+async def kernel_channels(
+    websocket: WebSocket, kernel_id, session_id, auth_config=Depends(get_auth_config)
+):
     accept_websocket = False
-    if auth_config.disable_auth:
+    if auth_config.mode == "noauth":
         accept_websocket = True
     else:
         cookie = websocket._cookies["fastapiusersauth"]
